      SUBROUTINE MATINV(MAX, N, A, M, B, IOP, DETERM, ISCALE, IPIVOT, IWK) 
!-----------------------------------------------
!   M o d u l e s 
!-----------------------------------------------
      USE vast_kind_param
!     F1.3
!***********************************************************************
!
!     PURPOSE - MATINV INVERTS A REAL SQUARE MATRIX A.
!               IN ADDITION THE ROUTINE SOLVES THE MATRIX
!               EQUATION AX=B,WHERE B IS A MATRIX OF CONSTANT
!               VECTORS. THERE IS ALSO AN OPTION TO HAVE THE
!               DETERMINANT EVALUATED. IF THE INVERSE IS NOT
!               NEEDED, USE GELIM TO SOLVE A SYSTEM OF SIMULTANEOUS
!               EQUATIONS AND DETFAC TO EVALUATE A DETERMINANT
!               FOR SAVING TIME AND STORAGE.
!
!     USE     - CALL MATINV(MAX,N,A,M,B,IOP,DETERM,ISCALE,IPIVOT,IWK)
!
!                 MAX - THE MAXIMUM ORDER OF A AS STATED IN THE
!                       DIMENSION STATEMENT OF THE CALLING PROGRAM.
!
!                 N   - THE ORDER OF A, 1.LE.N.LE.MAX.
!
!                 A   - A TWO-DIMENSIONAL ARRAY OF THE COEFFICIENTS.
!                       ON RETURN TO THE CALLING PROGRAM, A INVERSE
!                       IS STORED IN A.
!                       A MUST BE DIMENSIONED IN THE CALLING PROGRAM
!                       WITH FIRST DIMENSION MAX AND SECOND DIMENSION
!                       AT LEAST N.
!
!                 M   - THE NUMBER OF COLUMN VECTORS IN B.
!                       M=0 SIGNALS THAT THE SUBROUTINE IS
!                       USED SOLELY FOR INVERSION,HOWEVER,
!                       IN THE CALL STATEMENT AN ENTRY CORRE-
!                       SPONDING TO B MUST BE PRESENT.
!
!                 B   - A TWO-DIMENSIONAL ARRAY OF THE CONSTANT
!                       VECTOR B. ON RETURN TO CALLING PROGRAM,
!                       X IS STORED IN B. B SHOULD HAVE ITS FIRST
!                       DIMENSION MAX AND ITS SECOND AT LEAST M.
!
!                 IOP - COMPUTE DETERMINANT OPTION.
!                        IOP=0 COMPUTES THE MATRIX INVERSE AND
!                              DETERMINANT.
!                        IOP=1 COMPUTES THE MATRIX INVERSE ONLY.
!
!               DETERM- FOR IOP=0-IN CONJUNCTION WITH ISCALE
!                       REPRESENTS THE VALUE OF THE DETERMINANT
!                       OF A, DET(A),AS FOLLOWS.
!                        DET(A)=(DETERM)(10**100(ISCALE))
!                       THE COMPUTATION DET(A) SHOULD NOT BE
!                       ATTEMPTED IN THE USER PROGRAM SINCE IF
!                       THE ORDER OF A IS LARGER AND/OR THE
!                       MAGNITUDE OF ITS ELEMENTS ARE LARGE(SMALL),
!                       THE DET(A) CALCULATION MAY CAUSE OVERFLOW
!                     (UNDERFLOW). DETERM SET TO ZERO FOR
!                     SINGULAR MATRIX CONDITION, FOR EITHER
!                     I0P=1,OR 0. SHOULD BE CHECKED BY PROGRAMER
!                     ON RETURN TO MAIN PROGRAM.
!
!             ISCALE  - A SCALE FACTOR COMPUTED BY THE
!                       SUBROUTINE TO AVOID OVERFLOW OR
!                       UNDERFLOW IN THE COMPUTATION OF
!                       THE QUANTITY,DETERM.
!
!             IPIVOT  - A ONE DIMENSIONAL INTEGER ARRAY
!                       USED BY THE SUBPROGRAM TO STORE
!                       PIVOTOL INFORMATION. IT SHOULD BE
!                       DIMENSIONED AT LEAST N. IN GENERAL
!                       THE USER DOES NOT NEED TO MAKE USE
!                       OF THIS ARRAY.
!
!                IWK  - A TWO-DIMENSIONAL INTEGER ARRAY OF
!                       TEMPORARY STORAGE USED BY THE ROUTINE.
!                       IWK SHOULD HAVE ITS FIRST DIMENSION
!                       MAX, AND ITS SECOND 2.
!
!     REQUIRED ROUTINES-
!
!     REFERENCE        -FOX,L, AN INTRODUCTION TO NUMERICAL
!                              LINEAR ALGEBRA
!
!     STORAGE          - 542 OCTAL LOCATIONS
!
!     LANGUAGE         -FORTRAN
!     LIBRARY FUNCTIONS -ABS
!
!     RELEASED          - JULY 1973
!
!     LATEST REVISION   - JULY 29, 1981
!                         COMPUTER SCIECES CORPORATION
!                         HAMPTON, VA
!***********************************************************************
!
!...Translated by Pacific-Sierra Research 77to90  4.4D  16:36:33   4/10/03  
!...Switches: -yf12               
      IMPLICIT NONE
!-----------------------------------------------
!   D u m m y   A r g u m e n t s
!-----------------------------------------------
      INTEGER :: MAX 
      INTEGER :: N 
      INTEGER :: M 
      INTEGER :: IOP 
      INTEGER :: ISCALE 
      REAL(DOUBLE) :: DETERM 
      INTEGER :: IPIVOT(N) 
      INTEGER :: IWK(MAX,2) 
      REAL(DOUBLE) :: A(MAX,N) 
      REAL(DOUBLE) :: B(MAX,N) 
!-----------------------------------------------
!   L o c a l   V a r i a b l e s
!-----------------------------------------------
      INTEGER :: JCOLUM, ICOLUM, JROW, IROW, J, I, K, L, L1 
      REAL(DOUBLE) :: SWAP, T, AMAX, R1, R2, TMAX, PIVOT, PIVOTI 
!-----------------------------------------------
      EQUIVALENCE (IROW, JROW), (ICOLUM, JCOLUM), (AMAX, T, SWAP) 
!
!     INITIALIZATION                                                    
!
      ISCALE = 0 
!      R1=10.0**100.D0
      R1 = 10.0D0**100.D0 
!      R2=1.0/R1
      R2 = 1.0D0/R1 
      DETERM = 1.0D0 
      IPIVOT = 0 
      DO I = 1, N 
!
!       SEARCH FOR PIVOT ELEMENT
!
         AMAX = 0.0D0 
         DO J = 1, N 
            IF (IPIVOT(J) - 1 == 0) CYCLE  
            DO K = 1, N 
               IF (IPIVOT(K) - 1 > 0) GO TO 740 
               IF (IPIVOT(K) - 1 == 0) CYCLE  
               TMAX = ABS(A(J,K)) 
               IF (AMAX - TMAX >= 0.D0) CYCLE  
               IROW = J 
               ICOLUM = K 
               AMAX = TMAX 
            END DO 
         END DO 
         IF (AMAX < 0.D0) GO TO 740 
         IF (AMAX <= 0.D0) THEN 
            DETERM = 0.0D0 
            ISCALE = 0 
            GO TO 740 
         ENDIF 
         IPIVOT(ICOLUM) = 1 
!
!       INTERCHANGE ROWS TO PUT PIVOT ELEMENT ON DIAGONAL
!
         IF (IROW - ICOLUM /= 0) THEN 
            DETERM = -DETERM 
            DO L = 1, N 
               SWAP = A(IROW,L) 
               A(IROW,L) = A(ICOLUM,L) 
               A(ICOLUM,L) = SWAP 
            END DO 
            IF (M > 0) THEN 
               DO L = 1, M 
                  SWAP = B(IROW,L) 
                  B(IROW,L) = B(ICOLUM,L) 
                  B(ICOLUM,L) = SWAP 
               END DO 
            ENDIF 
         ENDIF 
         IWK(I,1) = IROW 
         IWK(I,2) = ICOLUM 
         PIVOT = A(ICOLUM,ICOLUM) 
         IF (IOP < 0) GO TO 740 
!
!       SCALE THE DETERMINANT                                           
!
         IF (IOP <= 0) THEN 
            PIVOTI = PIVOT 
            IF (ABS(DETERM) - R1 >= 0.D0) THEN 
               DETERM = DETERM/R1 
               ISCALE = ISCALE + 1 
               IF (ABS(DETERM) - R1 < 0.D0) GO TO 1060 
               DETERM = DETERM/R1 
               ISCALE = ISCALE + 1 
               GO TO 1060 
            ENDIF 
            IF (ABS(DETERM) - R2 <= 0.D0) THEN 
               DETERM = DETERM*R1 
               ISCALE = ISCALE - 1 
               IF (ABS(DETERM) - R2 <= 0.D0) THEN 
                  DETERM = DETERM*R1 
                  ISCALE = ISCALE - 1 
               ENDIF 
            ENDIF 
 1060       CONTINUE 
            IF (ABS(PIVOTI) - R1 >= 0.D0) THEN 
               PIVOTI = PIVOTI/R1 
               ISCALE = ISCALE + 1 
               IF (ABS(PIVOTI) - R1 < 0.D0) GO TO 320 
               PIVOTI = PIVOTI/R1 
               ISCALE = ISCALE + 1 
               GO TO 320 
            ENDIF 
            IF (ABS(PIVOTI) - R2 <= 0.D0) THEN 
               PIVOTI = PIVOTI*R1 
               ISCALE = ISCALE - 1 
               IF (ABS(PIVOTI) - R2 <= 0.D0) THEN 
                  PIVOTI = PIVOTI*R1 
                  ISCALE = ISCALE - 1 
               ENDIF 
            ENDIF 
  320       CONTINUE 
            DETERM = DETERM*PIVOTI 
         ENDIF 
!
!       DIVIDE PIVOT ROW BY PIVOT ELEMENT
!
         A(ICOLUM,ICOLUM) = 1.0D0 
         A(ICOLUM,:) = A(ICOLUM,:)/PIVOT 
         IF (M > 0) THEN 
            B(ICOLUM,:M) = B(ICOLUM,:M)/PIVOT 
         ENDIF 
!
!       REDUCE NON-PIVOT ROWS
!
         DO L1 = 1, N 
            IF (L1 - ICOLUM == 0) CYCLE  
            T = A(L1,ICOLUM) 
            A(L1,ICOLUM) = 0.0D0 
            A(L1,:) = A(L1,:) - A(ICOLUM,:)*T 
            IF (M <= 0) CYCLE  
            B(L1,:M) = B(L1,:M) - B(ICOLUM,:M)*T 
         END DO 
      END DO 
!
!     INTERCHANGE COLUMNS
!
      DO I = 1, N 
         L = N + 1 - I 
         IF (IWK(L,1) - IWK(L,2) == 0) CYCLE  
         JROW = IWK(L,1) 
         JCOLUM = IWK(L,2) 
         DO K = 1, N 
            SWAP = A(K,JROW) 
            A(K,JROW) = A(K,JCOLUM) 
            A(K,JCOLUM) = SWAP 
         END DO 
      END DO 
  740 CONTINUE 
      RETURN  
      END SUBROUTINE MATINV 

!      SUBROUTINE MIXUPD
!      IMPLICIT REAL*8(A-H,O-Z)
!      INCLUDE 'jmix.dat'
!      INCLUDE 'slat.dat'
!      INCLUDE 'profil.dat'
!  --- UPDATE VMRS IN ARRAY X FOR VERTICAL DISTRIBUTION RETRIEVALS
!      NPGAS=0
!      DO 11 IRETG=1,NRET
!      IF(IRTYPE(IRETG).EQ.1) GO TO 11
!  --- STORE UPDATED VMRS IN APPROPRIATE ARRAYS
!      NPGAS=NPGAS+1
!      NG=IRTYPE(IRETG)
!      DO 10 J=1,NG
!      A(J,1)=1.D0
!      DO 9 KEXP=2,NG
!    9 A(J,KEXP)=ALTFIT(J,NPGAS)**(KEXP-1)
!   10 B(J)=DLOG10(XFIT(J,NPGAS))
!  --- UPDATE THE VOLUME MIXING RATIOS IN THE ARRAY X
!      DO 9 K=1,KMAX
!      IF(ZM(K).LT.ALTFIT(1,NPGAS)) GO TO 7
!      IF(ZM(K).GT.ALTFIT(NG,NPGAS)) GO TO 8
!  --- COMPUTE VOLUME MIXING RATIO FROM LINEAR INTERPOLATION IN
!  --- XFIT ARRAY
!      DO 5 I=2,NG
!      IF(ALTFIT(I,NPGAS).GT.ZM(K)) GO TO 6
!    5 CONTINUE
!      STOP 'ERROR IN MIXUPD'
!    6 PART=(ZM(K)-ALTFIT(I-1,NPGAS))/(ALTFIT(I,NPGAS)-ALTFIT(I-1,NPGAS))
!      X(IRETG,K)=XFIT(I-1,NPGAS)+PART*(XFIT(I,NPGAS)-XFIT(I-1,NPGAS))
!      GO TO 9
!  --- ASSUME CONSTANT VMR BELOW LOWEST SPECIFIED ALTITUDE
!    7 X(IRETG,K)=XFIT(1,NPGAS)
!      GO TO 9
!  --- SCALE VMR PROFILE ABOVE HIGHEST SPECIFIED ALTITUDE
!    8 X(IRETG,K)=XORG(IRETG,K)*XFIT(NG,NPGAS)/XINIT(NG,NPGAS)
!    9 CONTINUE
!   11 CONTINUE
!      RETURN
!      END
