      SUBROUTINE SFIT2(BINPUT, INP_SPC, OUT_SPC, PT, MS, MX, XHAT, YHAT, NFIT, &
         NVAR, NLEV, RETFLG, WRTK, WRTSA, AFLAG, AGAS, AVAL, GASOUTTYPE)
!-----------------------------------------------
!   M o d u l e s
!-----------------------------------------------
      USE vast_kind_param
      USE params_M
      USE vibfn_dat_M
      USE zfft_dat_M
      USE slat_dat_M
      USE jmix_dat_M
      USE line_dat_M
      USE bands_dat_M
      USE spec_dat_M
      USE profil_dat_M
      USE wwv_dat_M
      USE molec_dat_M
      USE tfiles_dat_M
      USE solar
      USE opt
      USE diagnostic

!...Translated by Pacific-Sierra Research 77to90  4.4D  16:36:33   4/10/03
!...Switches: -yf12

!   Developed from CR's program NDSC, rev. 2.28, by BJC, 1995
!   version 3.1,  14 Dec 95
!   version 3.2,  29 Mar 96 - most include file dimension statements now
!                             parmeters.  update by changing all parameter
!                             statements
!   version 3.3,  8 Jun 96  - reads hitran format lines; lines no longer
!                             moved to grid points; pressure shift option added
!   version 3.4,  22 Sep 96 - option for fitting phase error added
!   version 3.5,  9 Jan 97  - extensive revision of input control file and
!                             output files; separate routine for empirical
!                             apodization, allowing input of tabular function,
!                             polynomial, or Fourier series, with the option of
!                             retrieval of the polynomial form (BJC)
!   version 3.6,  13 Aug 98 - parameterize and include filename length,
!                             get divwarn and iteration from opt,
!                             report convergence,divwarn, iteration done
!   version 3.7   7 Jan 00  - allow input of tabular phase function and input or
!                             retrieval of polynomial phase function, analogous to
!                             treatment of apodization function in 3.5. The combination
!                             of tabular apodization and phase functions allows use of
!                             an arbitrary ILS in a retrieval.
!                             Also allow input of a specified, fixed zero
!   version 3.7-A 21 Mar 00 - Expand hitran directory name from 50 chars to
!                             IFLNMSZ+20 (currently IFLNMSZ=200) so 220.
!   version 3.7-B 09 Apr 00 - Change to total REAL ( KIND=8 )  variables
!   version 3.7-C 10 Apr 00 - Change to total REAL ( KIND=8 )  constants
!   version 3.8   11 Jun 01 - Incorporate multiple updates combining Denver, Lauder
!                             and Langley versions.
!   version 3.8   19 Jun 01 - add mixout file
!   version 3.81  01 Mar 02 - 70 molec + more see file aanote JWH
!   version 3.82  24 Feb 03 - add channeling, correct comments, change
!                             Note: lines end with PWJ or pwj are revised by
!                             Wujian Peng in Change to implicit none, enhance
!                             output, BFILE common. Added nonfit gas list.
!   version 3.90  31 Aug 04 - Debugged multiple angle run, add reading
!                             ils.dat, added dof calculation.
!   version 3.91 26 Feb 05 - Sa to K file, FP checks, new solar spectra, runtime
!                            isotope extraction, fit-determined snr
!   version 3.92 25 Feb 07 - Add optional gas file output to make SIMUL type output.


!=====================================================
!
!        NDSC OPTIMAL ESTIMATION MIXING RATIO PROFILE INVERSION PROGRAM
!
!        MULTI-INTERVAL, MULTI-GAS BATCH VERSION -
!
!      ------------------------------------------------------------
!      TAPE7=FILE FOR MASS PATHS (INPUT) (MS file)
!      TAPE8=FILE FOR OBSERVED, CALCULATED, AND DIFFERENCES (OUTPUT)
!            (PBP file)
!      TAPE9=MASS WEIGHTED P & T PROFILE (INPUT) (PT file)
!      TAPE11=SOLAR CO LINE LIST (INPUT)
!      TAPE12=MULTI-FILE DATA SET OF STANDARD MIXING RATIOS
!             (INPUT) (MX file)
!             POINT-BY-POINT LISTING OF INTERFEROMETRIC SPECTRA
!      TAPE13=PARAMETERS INPUT VIA XINPUT INTERACTIVE PROGRAM
!             (INPUT) (binput file)
!      TAPE14=LINE DATA (INPUT) (cfgl files)
!      TAPE15=Input spectra (T15ASC file)
!      TAPE16=DETAILED OUTPUT FILE
!      TAPE17= .mxf output mix file
!      TAPE18=State vector output file
!      TAPE19=EAP/EPHS files
!      TAPE20=Summary output file
!      TAPE30=Channel Spectra data file 1 (debug output)
!      TAPE31= .short file  (output)
!      TAPE40=Channel Spectra data file 2 (debug output)
!      TAPE61=Sa.out FILE (output)
!      TAPE62=Sa.input FILE (input)
!      TAPE66=K file (output)
!             also TFIL66 + KT.out FILE (output)
!      TAPE67=SE.DAT FILE (output)
!      ----------------------------------------------------------

      IMPLICIT NONE
!-----------------------------------------------
!   G l o b a l   P a r a m e t e r s
!-----------------------------------------------
!-----------------------------------------------
!   D u m m y   A r g u m e n t s
!-----------------------------------------------
      INTEGER  :: NFIT, AFLAG, AGAS
      INTEGER  :: NVAR
      INTEGER  :: NLEV
      INTEGER  :: GASOUTTYPE
      LOGICAL  :: RETFLG
      LOGICAL  :: WRTK
      LOGICAL  :: WRTSA
      CHARACTER :: BINPUT*(IFLNMSZ)
      CHARACTER :: INP_SPC*(IFLNMSZ)
      CHARACTER :: OUT_SPC*(IFLNMSZ)
      CHARACTER :: PT*(IFLNMSZ)
      CHARACTER :: MS*(IFLNMSZ)
      CHARACTER :: MX*(IFLNMSZ)
      REAL(DOUBLE)  :: XHAT(NMAX), AVAL
      REAL(DOUBLE)  :: YHAT(MMAX)
!-----------------------------------------------
!   L o c a l   P a r a m e t e r s
!-----------------------------------------------
!-----------------------------------------------
!   L o c a l   V a r i a b l e s
!-----------------------------------------------
      INTEGER :: MAXLAY, NFITMX, MAXIT1, K, MSFORMAT, N, KK, NMASS, IRTEPHS, &
                 I, J, III, MAXRET, ISMIX, NPGAS, INDXX, KVERT,  &
                 JROW, JCOL, ITER, IND, IBAND, JSCAN, IB, &
                 IA, IOUT, IRTEAP, IAT, IBT, ICT, IAB, IBB, ICB, NEGFLAG, NEGLOOP
      INTEGER, DIMENSION(MAXSPE) :: KODE, NLAY
      REAL :: START_TIME, END_TIME
      REAL(DOUBLE) :: ZTOP, SCHAN_SCALE, CHAN_SCALE, SZERO, SPHS, PHS, SCOPAR, &
         COPAR, SBCKCRV, SBCKSL, BCKSL, SWSHFT, WSHFT, TOL, SNR, &
         DELZ, RHO, YMAX, SERR, SIGB, SIGC, WAVE, SIGZ, BCKCRV, AIRCOL
      REAL(DOUBLE), DIMENSION(12) :: FX
      REAL(DOUBLE), DIMENSION(MOLMAX,LAYMAX) :: VERSUM, VOSUM
      REAL(DOUBLE), DIMENSION(MMAX) :: Y, SED
      REAL(DOUBLE), DIMENSION(NMAX) :: PARM
      !REAL(DOUBLE), DIMENSION(NMAX,NMAX) :: SA ! nxn matrix in opt
      REAL(DOUBLE), DIMENSION(NMAX) :: XAPR
      REAL(DOUBLE), DIMENSION(NMAX) :: SPARM
      REAL(DOUBLE), ALLOCATABLE :: SAOUT(:,:)
      REAL(DOUBLE), DIMENSION(LAYMAX) :: ZBAR
      LOGICAL :: CNVERG, DEBUG, DIVWARN, FILOPEN
      CHARACTER :: ATDATA*200
      CHARACTER , DIMENSION(NMAX) :: PNAME*14
      CHARACTER , DIMENSION(5) :: CPNAM*14
      CHARACTER :: XNAM*7, TIME*10, DATE*10, ZONE*10
!-----------------------------------------------
!
!          EXPLANATION OF SOME PARAMETERS AND VARIABLES
!  *********************************************************************
!
!       MAXIMUM NUMBER OF SPECTRAL DATA POINTS=MMAX
!       MAXIMUM NUMBER OF MONOCHROMATIC POINTS/BANDPASS=MAXCROSS
!       MAXIMUM NUMBER OF GASES=MAXGAS
!       MAXIMUM NUMBER OF RETRIEVAL GASES=MOLMAX
!       MAXIMUM NUMBER OF ATMOSPHERIC LAYERS=LAYMAX
!       MAXIMUM NUMBER OF LINES=LNMAX
!       MAXIMUM NUMBER OF FITTING PARAMETERS=NMAX
!       MAXIMUM NUMBER OF SPECTRA=MAXSPE
!
!  *********************************************************************
!
!        SSL = LINE STRENGTH (CM-1/(ATM.CM)) AT TEMPERATURE T IN LAYER K
!        DELNU = HALF-WIDTH OF INTERVAL FOR CALCULATING EACH LINE SHAPE
!        WAVE1,WAVE2 = BEGINNING, ENDING WAVENUMBERS FOR COMPUTATION
!               OF MONOCHROMATIC TRANSMITTANCES
!        WAVE3,WAVE4 = BEGINNING, ENDING WAVENUMBERS FOR INTEGRATION
!        DN = POINT SPACING FOR MONOCHROMATIC CALCULATIONS
!        Z, P, T = HEIGHT, PRESSURE, TEMPERATURE
!
!
      CALL CPU_TIME (START_TIME)
      UFLAG = AFLAG
      UGAS = AGAS
      UVAL = AVAL
      TFIL07 = MS
      TFIL09 = PT
      TFIL12 = MX
      TFIL13 = BINPUT
      TFIL15 = INP_SPC
      IF (OUTPUT_CHANNEL_FILES) THEN
         TFIL30 = 'spectra.data1'
         TFIL40 = 'spectra.data2'
      ELSE
         TFIL30 = '-not_used-'
         TFIL40 = '-not_used-'
      ENDIF
      IF (OUTPUT_SEFILE) THEN
         TFIL67 = 'se.dat'
      ELSE
         TFIL67 = '-not_used-'
      ENDIF

      WRITE (*, *)
      WRITE (*, *) VERSION
      OPEN(UNIT=13, FILE=TFIL13, STATUS='OLD', ERR=666, POSITION='asis')
      CALL FILINP
! --- added short output
      OPEN(UNIT=31, FILE=TFIL31, STATUS='UNKNOWN', ERR=669, POSITION='asis')
      OPEN(UNIT=7, FILE=TFIL07, STATUS='OLD', ERR=6661, POSITION='asis')
      OPEN(UNIT=8, FILE=TFIL08, STATUS='unknown', ERR=5551, POSITION='asis')
      OPEN(UNIT=9, FILE=TFIL09, STATUS='OLD', ERR=6662, POSITION='asis')
      OPEN(UNIT=16, FILE=TFIL16, STATUS='unknown', ERR=5552, POSITION='asis')
      WRITE (16, *) VERSION
      CALL DATE_AND_TIME (DATE, TIME, ZONE)
      WRITE (16, *) 'Running ', DATE(5:6), '/', DATE(7:8), '/', DATE(1:4), '  '&
         , TIME(1:2), ':', TIME(3:4), ':', TIME(5:6)

      WRITE (31, *) VERSION

      NGINC = 0
      ZTOP = 0.D0
      MAXLAY = LAYMAX
      NFITMX = MMAX
      NSOLAR = 0
      DEBUG = .FALSE.                     ! used in opt.f
      NEAPRT = 0                          ! set to indicate no eapf information
      NEPHSRT = 0                         ! set to indicate no ephs information
      PARM = 0.0D0                        ! initialize entire array
      SA(:,:) = 0.0D0                     ! initialize entire array
      XHAT(:) = 0.0D0

! --- ZTOP arbitrarily set to 100km - top of top layer should be in pt file
!     see notes - read in ztop from 1st line if its there else its 100km
      READ (9, 588, END=12) Z(1), P(1), T(1), ZTOP
      IF (ZTOP == 0.D0) ZTOP = 100.0D0
      ZBAR(1) = 0.5D+00*(ZTOP + Z(1))
      PMB(1) = P(1)
      P(1) = P(1)/BAR

      DO K = 2, MAXLAY
         READ (9, 590, END=12) Z(K), P(K), T(K)
!  --- TEMPERATURE UNCERTAINTY ESTIMATE
!      SHOUD BE COMMENTED OUT FOR NORMAL RUN
!      PRINT *, 'TEMPERATURE CHANGE!!!'
!         T(K) = T(K) +3
         ZBAR(K) = 0.5D+00*(Z(K-1)+Z(K))
!  --- CONVERT PRESSURE TO ATM
         PMB(K) = P(K)
         P(K) = P(K)/BAR
      END DO
   12 CONTINUE
      CLOSE(9)

      KMAX = K - 1
      NLEV = KMAX

!  --- MEAN ALTITUDES OF EACH LAYER
      ZM(1) = 0.5D+00*(ZTOP + Z(1))
      ZM(2:KMAX) = 0.5D+00*(Z(:KMAX-1)+Z(2:KMAX))

! --- READ INVERSION PARAMETERS
!     NOW THAT WE HAVE KMAX
      WRITE (*, *) ''
      WRITE (*, *) ' Reading input file...'
      CALL PINP (MAXIT1,NLEV, NEGFLAG)
      WRITE (16, 100)

! --- NOW PRINT OUT PRESSURE / TEMPERATURE PROFILE
      WRITE (16, 550) ' SETTING ZTOP = ', ZTOP, 'km.'
      WRITE (16, 590) Z(1), PMB(1), T(1)
      DO K=2, KMAX
         WRITE (16, 590) Z(K), PMB(K), T(K)
      ENDDO
      WRITE (16, 101)

!  --- READ IN MASS PATH DATA FROM TAPE7
!  --- MASS PATHS ARE TOTAL MASS PATHS IN CM*ATM
      MSFORMAT = 0
      DO K = 1, MAXSPE
         IF (K == 1) THEN
            READ (7, 102, END=4) KODE(K), N, MSFORMAT
            WRITE (16, *)
            IF (MSFORMAT == 1) THEN
               WRITE (16, *) 'MS file will be read LIST I/O'
            ELSE
               WRITE (16, *) 'MS file will be read (8E10.4)'
            ENDIF
         ELSE
            READ (7, 102, END=4) KODE(K), N
         ENDIF
         WRITE (16, 102) KODE(K), N
         IF (MSFORMAT == 0) THEN
            READ (7, 103) (CCC(K,KK),KK=1,N)
         ELSE
            READ (7, *) (CCC(K,KK),KK=1,N)
         ENDIF
         WRITE (16, 106) (CCC(K,KK),KK=1,N)
         NLAY(K) = N
      END DO
    4 CONTINUE
      NMASS=-1
      DO III=1,K-1
         IF (KODE(III) .EQ. 999) THEN
            NMASS = III
         ENDIF
      END DO
      IF (NMASS .LT. 0) THEN
         PRINT *,'Could not find 999 in MS file'
         STOP 'BAD MS FILE'
      ENDIF
      CLOSE(7)

!  --- FIND MAXIMUM MASS PATH FOR EACH LAYER
      DO KK = 1, KMAX
         PMASMX(KK) = 0.D0
         PMASMX(KK) = DMAX1(MAXVAL(CCC(:NMASS,KK), MASK=NLAY(:NMASS)>=KK .AND. &
            KODE(:NMASS)/=999),PMASMX(KK))
      END DO
!     SELECTION OF BANDPASSES AND LINES FOR INVERSION
!      WRITE(16,2001)
!      WRITE(16,2002)
!      WRITE(16,2003)
      READ (13, *) WAVFAC, PMAX, OMEGA, IAP, NBAND, IFPS, IEAP, NEAP, IEPHS, &
         NEPHS
      READ (13, *) ISPARM, NBACK, IFCO, IFDIFF, IPHASE, IRTEAP, IRTEPHS
      READ (13, *) WSHFT, SWSHFT, BCKSL, SBCKSL, BCKCRV, SBCKCRV, COPAR, SCOPAR&
         , PHS, SPHS, SZERO, EAPPAR, SEAPPAR, EPHSPAR, SEPHSPAR, CHAN_SCALE, &
         SCHAN_SCALE                             !pwj
      WRITE (16, 1008)
      WRITE (16, 1018) WAVFAC, PMAX, OMEGA, IAP, NBAND, IFPS, IEAP, NEAP, IEPHS&
         , NEPHS
      WRITE (16, 1009)
      WRITE (16, 1019) ISPARM, NBACK, IFCO, IFDIFF, IPHASE, IRTEAP, IRTEPHS
      WRITE (16, 1010)
      WRITE (16, 10101) WSHFT, SWSHFT, BCKSL, SBCKSL, BCKCRV, SBCKCRV, COPAR, &
         SCOPAR, PHS, SPHS, SZERO, EAPPAR, SEAPPAR, EPHSPAR, SEPHSPAR, &
         CHAN_SCALE, SCHAN_SCALE
      IF (IEAP/=2 .AND. IRTEAP==1) GO TO 667
      IF (IEPHS/=2 .AND. IRTEPHS==1) GO TO 668

!     ---- SOLAR CO PARAMETERS
      IF (IFCO /= 0) THEN
!         WRITE (16, 602)
!         READ (13, *) TREFCO, TEMPCO
!         WRITE (16, 105) TREFCO, TEMPCO
         WRITE (16, 603)
!         READ (13, *) (CPARM(N),N=1,5)
!         WRITE (16, 105) (CPARM(N),N=1,5)

         DO N = 1, 5
            CPARM(N) = 0.0
            ICFIX(N) = 0
         END DO
         READ (13, *) CPARM(4)
         WRITE (16, 105) CPARM(4)
! --- define names of solar parameters
         CPNAM(1) = 'Sol - n/a'
         CPNAM(2) = 'Sol - n/a'
         CPNAM(3) = 'Sol - n/a'
         CPNAM(4) = 'SolLnShft'
         CPNAM(5) = 'Sol - n/a'
!  --- ADD ONE TO WAVENUMBER SHIFT PARAMETER TO AVOID THE CASE OF ZERO
!  --- INITIAL SHIFT
         CPARM(4) = CPARM(4) + 1.D0
!  --- ADD ONE TO SOLAR CO LORENTZ PARAMETER TO AVOID THE CASE OF ZERO
!  --- INITIAL LORENTZ WIDTH
!         CPARM(5) = CPARM(5) + 1.D0
!  --- STORE INITIAL VALUES FOR MINNAERT PARAMETERS
         CIPARM = CPARM
         WRITE (16, 532)
!         READ (13, *) (ICFIX(N),N=1,5)
!         WRITE (16, 102) (ICFIX(N),N=1,5)
         READ (13, *) ICFIX(4)
         WRITE (16, 102) ICFIX(4)
      ENDIF

! --- CONVERT FOV DIAMETER FROM MILLIRADIANS TO SOLID ANGLE
      FOVDIA = OMEGA
      OMEGA = 2.0D0*PI*(1.D0 - COS(1.D-03*OMEGA/2.D0))

      IF (NBACK<1 .OR. NBACK>3) GO TO 664
      IF (ISPARM<0 .OR. ISPARM>3) GO TO 665
      !write(*,*) 'nband: ', nband
      NGIDX(:,:,:)=0
      DO I = 1, NBAND
         WRITE (16, 201) I
! --- Note: lines end with PWJ are revised by Wujian Peng in July,2002  !pwj
         READ (13, *) WAVE3(I), WAVE4(I), NRETB(I), ZSHIFT(I,1), IZERO(I), &
            NBEAM_OF_BAND(I), CHANNEL_MODEL_OF_BAND(I)
         WRITE (16, 1002) WAVE3(I), WAVE4(I), NRETB(I), ZSHIFT(I,1), IZERO(I), &
            NBEAM_OF_BAND(I), CHANNEL_MODEL_OF_BAND(I)
! --- READ CHANNEL PARAMETERS IF EXISTS---------------------------!pwj
         K = NBEAM_OF_BAND(I)
         IF (K > 0) THEN
            CALL READ_CHANNEL_PARMS (I, K, 13, 16)
         ENDIF

         K = NRETB(I)
         DO J = 1, K
            WRITE (16, 1003) I
            READ (13, 1004) XNAM, MINB(I,J), MAXB(I,J)
            WRITE (16, 1005) XNAM, MINB(I,J), MAXB(I,J)
            DO N = 1, NRET
               IF (XNAM == NAME(IGAS(N))) GO TO 43
            END DO
            WRITE (16, 610) XNAM, WAVE3(I), WAVE4(I)
            RETURN
   43       CONTINUE
            IGASB(I,J) = IGAS(N)
            NGIDX(N,0,I) = 1
         END DO
      END DO
      DO III = 2, NBAND
         IF (WAVE3(III) >= WAVE3(1)) CYCLE
         WRITE (6, *) 'Micro-Windows must be in ascending wavenumber order'
         STOP 'Micro-Windows not in ascending order'
      END DO

! --- READ IN NUMBER OF SPECTRA, DEFAULT SNR, FIT TOLERANCE, # INCLUDED NONFIT GASES
      WRITE (16, 520)
      READ (13, *) NSPEC, SNR, TOL, NGINC
      WRITE (16, 104) NSPEC, SNR, TOL, NGINC

! --- READ IN GAS NAMES AND INITIAL PROFILE SCALE FOR NOT FIT GASES
      IF (NGINC /= 0) THEN
         WRITE (16, 521)
         DO I = 1, NGINC
            READ (13, *) GASINC(I), SCLINC(I)
            WRITE (16, 522) GASINC(I), SCLINC(I)
         END DO
      ENDIF

! --- READ SPECTRAL CODES AND DATA FILE NAMES
      DO K = 1, NSPEC
         WRITE (16, 530)
         READ (13, 504) ISPEC(K), N
         WRITE (16, 504) ISPEC(K), N

    ! new in 393 ???
    !IF (K > 1) THEN
     !       DO I = 1, NBAND
     !          ZSHIFT(I,K)=ZSHIFT(I,1)  ! COPY BAND SHIFT FROM FIRST SPECTRA TO THIS SPECTRA
     !       ENDDO
     !    ENDIF

!  -- INPUT SPECTRUM FILE NAMES
         DO I = 1, N
            WRITE (16, 3885)
            READ (13, 3886) ATDATA
            WRITE (16, 3887) ATDATA(1:LEN_TRIM(ATDATA))
         END DO

! --- LOCATE SPECTRUM IN TABLE OF MASS PATH DATA-STORE KSCAN VALUE
         DO KK = 1, NMASS
            IF (ISPEC(K) == KODE(KK)) GO TO 47
         END DO
         PRINT *, 'CINPUT MASS PATH ID NOT FOUND IN MASS PATH TABLE'
         PRINT *, ISPEC(K), KODE(KK)
         !PRINT *, 'PROCEDING ANYWAY'
         !GOTO 47
         WRITE (6, 540)
         WRITE (16, 540)
         RETURN
   47    CONTINUE
         KSCAN(K) = KK
         KZTAN(K) = NLAY(KSCAN(K))
         MAXRET = KZTAN(K)
      END DO

!  --- CALL SETUP ROUTINE
      WRITE (*, *) ' Setting up spectral interval(s)...'
      CALL SETUP

!  --- INITIALIZE PARAMETERS FOR RETRIEVAL
      NVAR = 0
!  --- INTIALIZE VALUES FOR RETRIEVAL
!  --- BACKGROUND FITTING
      IF (NBACK == 1) THEN
      ELSE
         IF (NBACK == 2) THEN
            IF (NFITS > 0) THEN
!  --- BACKGROUND SLOPE - NBACK=2
               PNAME(:NFITS) = 'BckGrdSlp'
               PARM(:NFITS) = BCKSL
               SPARM(:NFITS) = SBCKSL
!  --- BACKGROUND CURVATURE - NBACK=3
               NVAR = NFITS
            ENDIF
         ELSE
            IF (NFITS > 0) THEN
!  --- BACKGROUND SLOPE - NBACK=2
               PNAME(NVAR+1:NFITS*2-1+NVAR:2) = 'BckGrdSlp'
               PARM(NVAR+1:NFITS*2-1+NVAR:2) = BCKSL
               SPARM(NVAR+1:NFITS*2-1+NVAR:2) = SBCKSL
!  --- BACKGROUND CURVATURE - NBACK=3
               PNAME(NVAR+2:NFITS*2+NVAR:2) = 'BckGrdCur'
               PARM(NVAR+2:NFITS*2+NVAR:2) = BCKCRV
               SPARM(NVAR+2:NFITS*2+NVAR:2) = SBCKCRV
               NVAR = NFITS*2 + NVAR
            ENDIF
         ENDIF
      ENDIF
      NBKFIT = (NBACK - 1)*NFITS

! ---  NO WAVENUMBER SHIFT
      IF (ISPARM /= 0) THEN

!  --- SINGLE WAVELENGTH SHIFT FOR ALL BANDPASSES
         IF (ISPARM <= 1) THEN
            NVAR = NVAR + 1
            PNAME(NVAR) = 'SWNumShft'
            PARM(NVAR) = WSHFT
            SPARM(NVAR) = SWSHFT
            NSHIFT = 1
         ELSE
!  --- INDEPENDENT WAVELENGTH SHIFT FOR EACH BANDPASS (ISPARM=2)
!  --- OR INDEPENDENT WAVELENGTH SHIFT FOR EACH FITTING (ISPARM=3)
            IF (ISPARM == 2) N = NBAND
            IF (ISPARM == 3) N = NFITS
            IF (N > 0) THEN
               PNAME(NVAR+1:N+NVAR) = 'IWNumShft'
               PARM(NVAR+1:N+NVAR) = WSHFT
               SPARM(NVAR+1:N+NVAR) = SWSHFT
               NVAR = N + NVAR
            ENDIF
            NSHIFT = N
         ENDIF
      ENDIF

!  --- FIT ZERO LEVELS IF IZERO=1
!  --- TOTAL NUMBER OF ZERO LEVEL FITS=NZERO
      NZERO = 0
      DO I = 1, NBAND
         IF (IZERO(I) == 0) CYCLE
         N = NSCAN(I)
         IF (N > 0) THEN
            PNAME(NVAR+1:N+NVAR) = 'ZeroLev'
            PARM(NVAR+1:N+NVAR) = ZSHIFT(I,1)
            SPARM(NVAR+1:N+NVAR) = SZERO
            NVAR = N + NVAR
            NZERO = N + NZERO
         ENDIF
      END DO

!  --- EMPIRICAL APODIZATION
      IF (IRTEAP /= 0) THEN
         NEAPRT = NEAP
         IF (NEAPRT > 0) THEN
            EAPF0(:NEAPRT) = EAPF(:NEAPRT)
            PNAME(NVAR+1:NEAPRT+NVAR) = 'EmpApdFcn'
            PARM(NVAR+1:NEAPRT+NVAR) = EAPPAR
            SPARM(NVAR+1:NEAPRT+NVAR) = SEAPPAR
            NVAR = NEAPRT + NVAR
         ENDIF
      ENDIF

!  --- EMPIRICAL PHASE FUNCTION
      IF (IRTEPHS /= 0) THEN
         NEPHSRT = NEPHS
         IF (NEPHSRT > 0) THEN
            EPHSF0(:NEPHSRT) = EPHSF(:NEPHSRT)
            PNAME(NVAR+1:NEPHSRT+NVAR) = 'EmpPhsFnc'
            PARM(NVAR+1:NEPHSRT+NVAR) = EPHSPAR
            SPARM(NVAR+1:NEPHSRT+NVAR) = SEPHSPAR
            NVAR = NEPHSRT + NVAR
         ENDIF
      ENDIF

!  --- SOLAR LINES INCLUSION F. HASE EMPIRICAL LISTING
      IF (IFCO /= 0) THEN
         DO I = 1, 5
            IF (ICFIX(I) == 0) CYCLE
            NVAR = NVAR + 1
            NSOLAR = NSOLAR + 1
            IF (NSOLAR == 1) NSOLAR1 = NVAR + 1
            NSOLAR2 = NVAR + 2
            SELECT CASE (I)
            CASE (1)
               PNAME(NVAR) = CPNAM(1)
            CASE (2)
               PNAME(NVAR) = CPNAM(2)
            CASE (3)
               PNAME(NVAR) = CPNAM(3)
            CASE (4)
               PNAME(NVAR) = CPNAM(4)
            CASE (5)
               PNAME(NVAR) = CPNAM(5)
            END SELECT
            PARM(NVAR) = COPAR
            SPARM(NVAR) = SCOPAR
         END DO
      ENDIF

!  --- DIFFERENTIAL WAVENUMBER SHIFT FOR RETRIEVAL GASES
      NDIFF = 0
      IF (IFDIFF/=0 .AND. NRET>1) THEN
         IF (NRET - 1 > 0) THEN
            PNAME(NVAR+1:NRET-1+NVAR) = 'DWNumShft'
            PARM(NVAR+1:NRET-1+NVAR) = WSHFT
            SPARM(NVAR+1:NRET-1+NVAR) = SWSHFT
            NDIFF = NRET - 1
            NVAR = NRET - 1 + NVAR
         ENDIF
      ENDIF

!  --- SKIP IF IPHASE=0; FIT FOR PHASE ERRORS IF IPHASE=1
!  --- TOTAL NUMBER OF PHASE ERROR FITS=NPHASE
      NPHASE = 0
      IF (IPHASE /= 0) THEN
         DO I = 1, NBAND
            N = NSCAN(I)
            IF (N > 0) THEN
               PNAME(NVAR+1:N+NVAR) = 'SPhsErr'
               PARM(NVAR+1:N+NVAR) = PHS
               SPARM(NVAR+1:N+NVAR) = SPHS
               NVAR = N + NVAR
               NPHASE = N + NPHASE
            ENDIF
         END DO
      ENDIF

!  ---  RETRIEVAL GAS MIXING RATIOS
      ISMIX = NVAR ! mixing ratio at ismix +1 !!!
      NPGAS = 0
      DO KK = 1, NRET
         NGIDX(KK,1,0) = NVAR + 1
         IF (IRTYPE(KK) /= 1) THEN
!  --- RETRIEVING VERTICAL PROFILE
            N = IRTYPE(KK)
            NPGAS = NPGAS + 1
            PNAME(NVAR+1:N+NVAR) = NAME(IGAS(KK))
            PARM(NVAR+1:N+NVAR) = 1.D0
            SPARM(NVAR+1:N+NVAR) = SIG(:N,NPGAS)
            NVAR = NVAR + N
         ELSE
!  --- SCALING VERTICAL DISTRIBUTION
            NVAR = NVAR + 1
            PNAME(NVAR) = NAME(IGAS(KK))
            PARM(NVAR) = COLSF(KK)
            SPARM(NVAR) = SCOLSF(KK)
         ENDIF
         NGIDX(KK,2,0) = NVAR
      END DO

      IF(NPGAS.GT.0) then
!        Commented out MIXINT call 1/23/03 since it fills the XINIT
!          array and XINIT hasn't been used at least since sfit2 3.3
!          It was previously used in the MIXUPD routine in matinv.f
!         WRITE(*,*)' Initializing profile retrieval arrays...'
!         CALL MIXINT
      ENDIF

! --- INSERT  CHANNEL PARAMETERS INTO STATE VECTOR PARM()------- !PWJ
      CALL INSERT_CHANNEL_PARMS (NVAR, PARM, DBLE(CHAN_SCALE), DBLE(SCHAN_SCALE), PNAME, SPARM)

!  --- TEST FOR OVERFLOWS
      IF (NVAR > NMAX) GO TO 556
      NFIT = NATMOS
      IF (NFIT > NFITMX) GO TO 557
!  --- SETUP ARRAYS FOR OPTIMAL ESTIMATION SUBROUTINE
!  --- FILL MATRIX SED (COVARIANCE OF MEASURED SPECTRUM-OFFDIAGNAL
!  --- ELEMENTS ASSUMED TO BE ZERO)
      WRITE (*, *) ' Initializing variance vector...'
      CALL FILSE (SED, NFIT, SNR)

!      SIG2=1./(SNR*SNR)
!      SIG2=1.D0/(SNR*SNR)
!      DO 3733 I=1,NFIT
! 3733 SED(I)=SIG2
      WRITE (16, 3695) NFIT, NVAR
      WRITE (16, 3696)
      ICOUNT = 0

!  --- FILL DIAGONAL ELEMENTS OF SA
      DO I = 1, NVAR
         SA(I,I) = SPARM(I)*SPARM(I)
      ENDDO

!  --- OFF DIAGONAL ELEMENTS OF SA MATRIX (A PRIORI COMPONENTS)
      IF (NPGAS /= 0) THEN
         INDXX = ISMIX
         NPGAS = 0
         DO KK = 1, NRET
            N = IRTYPE(KK)
            IF ( N /= 1 ) THEN
               !PRINT *, KK, N
               NPGAS = NPGAS + 1
               SELECT CASE ( IFOFF(KK) )
               CASE ( 1:3 )
!  --- FILL OFF DIAGONAL ELEMENTS OF SA
               DO I = 1, N
                 DO J = 1, N
                   IF (I == J) CYCLE
                   JROW = I + INDXX
                   JCOL = J + INDXX
                   IF( ZBAR(I) < ZGMIN(KK) ) CYCLE
                   IF( ZBAR(J) < ZGMIN(KK) ) CYCLE
                   IF( ZBAR(I) > ZGMAX(KK) ) CYCLE
                   IF( ZBAR(J) > ZGMAX(KK) ) CYCLE

                   DELZ = ZBAR(I) - ZBAR(J)

                   SELECT CASE ( IFOFF(KK) )
                   CASE (1)       !gaussian
                     RHO = (ALOGSQ*DELZ/ZWID(KK))**2
                     RHO = MIN( RHO, 664.0D0 )
                     SA(JROW,JCOL) = SPARM(JROW)*SPARM(JCOL)*EXP(-RHO)
                   CASE (2)       !exponential
                     RHO = ABS(ALOGSQ*DELZ/ZWID(KK))
                     RHO = MIN( RHO, 664.0D0 )
                     SA(JROW,JCOL) = SPARM(JROW)*SPARM(JCOL)*EXP(-RHO)
                   CASE (3)
                            STOP "IFOFF=3 not supported"
                   END SELECT
                 END DO
               END DO
! --- READ IN FULL COVARIANCE FROM FILE
               CASE ( 4 )
                  INQUIRE( UNIT=62, OPENED=FILOPEN )
                  IF ( .NOT. FILOPEN ) THEN
                     OPEN(62, FILE=TFIL62, STATUS='unknown', ERR=4443, POSITION='asis')
                  ENDIF
                  DO I = 1, N
                     READ( 62,* ) (SA( I+INDXX, J+INDXX), J=1, N)
                  END DO
               END SELECT
            ENDIF
            INDXX = INDXX + IRTYPE(KK)
         END DO
      ENDIF
      INQUIRE( UNIT=62, OPENED=FILOPEN )
      IF ( FILOPEN ) CLOSE( 62 )

      Y(:NFIT) = TOBS(:NFIT)
      XAPR = PARM

! --- WRITE OUT COVARIENCE MATRIX
! --- NOT! WRITE OUT IN REVERSE, REVERSE FORM
      IF (WRTSA) THEN
         OPEN(61, FILE=TFIL61, STATUS='unknown', ERR=4441, POSITION='asis')
         INDXX = ISMIX
         DO KK = 1, NRET
            N = IRTYPE(KK)
            IF( N /= 1) THEN
               NPGAS = NPGAS + 1
               IF ( .NOT. ALLOCATED( SAOUT )) ALLOCATE( SAOUT( N, N ))

               WRITE (61, '(3X,45A14)') (PNAME(I),I = INDXX+1, INDXX + N)
               DO I = 1, N
                  DO J = 1, N
                     JROW = I + INDXX
                     JCOL = J + INDXX
                     SELECT CASE ( TRIM( TFIL61 ))
                     CASE ( 'Sa.norm' )
                         ! fractional form
                         SAOUT(I,J) = SA(JROW,JCOL)
                     CASE ( 'Sa.pcol' )
                         ! partial column [(molec/cm^2)^2]
                         RHO = XORG(KK,I)*XORG(KK,J)*CCC(NMASS,I)*CCC(NMASS,J)
                         SAOUT(I,J) = SA(JROW,JCOL) * RHO
                     CASE ( 'Sa.vmr' )
                        ! vmr [ppm^2]
                        RHO = XORG(KK,I)*XORG(KK,J)*1.0D12
                        SAOUT(I,J) = SA(JROW,JCOL) * RHO
                     CASE DEFAULT
                         SAOUT(I,J) = SA(JROW,JCOL)
                     END SELECT
                  END DO
               END DO
               DO I=1,IRTYPE(KK)
                  WRITE (61, '(45ES14.6)') (SAOUT(I,J),J=1,IRTYPE(KK))
               END DO
               DEALLOCATE( SAOUT, stat=k )
            ENDIF
            INDXX = INDXX + IRTYPE(KK)
         END DO
         CLOSE(61)
      ENDIF

!  --- WRITE OUT FULL SA MATRIX - OR COMMENT OUT - now in K file
      OPEN(61, FILE="SA.complete", STATUS='unknown', ERR=4441, POSITION='asis')
      WRITE (61, '(3X,255A14)') (PNAME(I),I = 1, NVAR)
      DO I=1,NVAR
         WRITE (61, '(255ES14.6)') (SA(I,J),J=1,NVAR)
      END DO
      CLOSE(61)

!  --- SAVE NVAR KEY TO DETAIL
      WRITE(16,502) (PNAME(I),I=1,NVAR)
      WRITE(16,*)''
!     WRITE(16,888)(XAPR(I),I=1,NVAR)

      NEGLOOP = 0
200   SE(:NFIT) = SED(:NFIT)

      OPEN( UNIT=89, FILE='Parm.out' )
      WRITE(89, *) NVAR
      WRITE(89, '(255(12X,A14))') (PNAME(I),I = 1, NVAR)

!  --- CALL OPTIMAL ESTIMATION SUBROUTINE
      WRITE (*, *) ' Beginning iterative retrieval loop...'
      CALL OPT_3 (Y, PARM, XHAT, YHAT, NFIT, NVAR, CNVERG, &
         MAXIT1, TOL, DEBUG, RETFLG, DIVWARN, ITER, WRTK, SNR, ISMIX, NLEV, GASOUTTYPE )

      CLOSE(89)

!  --- IF FM HAD ABNORMAL TERMINATION, THEN JUST LEAVE
      IF (Tflg) GO TO 700

      !GOTO 202
!  --- DECREASE SNR 2 TIMES TO TRY TO GET A FIT
!  --- AT START IF NEGFLAG == -2 THEN END HERE
!  --- IF 0 THEN ITERATE ON NEG VMR
      J = 1
      DO KK=1,NLEV
         IF((X(J,KK).LT.0.0).AND.(IRTYPE(J).NE.1)) THEN
               NEGFLAG = NEGFLAG +1
               NEGLOOP = NEGLOOP +1
            PRINT *,''
            PRINT *," Final vmr profile of target contains negative values."
               PRINT *,''
               EXIT
         ENDIF
      ENDDO

      IF( NEGLOOP .EQ. 5 ) GOTO 202
      IF( NEGFLAG .LE. 0 ) THEN
         GOTO 202
      ELSE
          SED(:NFIT) = SED(:NFIT) / (0.36)
          SNR = SNR * 0.6
          PRINT *," Reducing SNR...", NEGFLAG, NEGLOOP, NINT(SNR)
          NEGFLAG = 0
          GOTO 200
      ENDIF

!     WRITE(*,*)(XHAT(i),i=1,nvar)
 202  IF (.NOT.RETFLG) THEN
         OPEN(UNIT=19, FILE=OUT_SPC, STATUS='unknown', ERR=4442, POSITION=&
            'asis')
         IND = 0
         DO I = 1, NBAND
            DO K = 1, NSPEC
               WRITE (19, *) 'Simulation from opt_fm'
               WRITE (19, *) WSTART(I), WSTOP(I), SPAC
               WRITE (19, *) NPRIM(I)
               DO J = 1, NPRIM(I)
                  WRITE (19, *) YHAT(IND+J)
               END DO
               IND = IND + NPRIM(I)
            END DO
         END DO
         CLOSE(19)
      ENDIF


      !PRINT *, MAXVAL(TOBS(:NFIT)), MAXVAL(Y(:NFIT)), MAXVAL(YHAT(:NFIT))

! --- RENORMALIZATION OF FINAL SPECTRA
      IND = 0
      DO I = 1, NBAND
         DO K = 1, NSPEC
!            WRITE(*,*)(y(ind+j),j=1,NPRIM(i))
!            WRITE(*,*)(YHAT(ind+j),j=1,NPRIM(i))
!         YMAX=0.
            YMAX = 0.D0
            DO J = 1, NPRIM(I)
               YMAX = MAX(YMAX,YHAT(IND+J))
            END DO
!            WRITE(*,*)YMAX
             !print *, i, ind, nprim(i)
            YHAT(IND+1:NPRIM(I)+IND) = YHAT(IND+1:NPRIM(I)+IND)/YMAX
            TOBS(IND+1:NPRIM(I)+IND) = TOBS(IND+1:NPRIM(I)+IND)/YMAX
!            WRITE(*,*)YMAX
            IND = IND + NPRIM(I)
         END DO
      END DO

!  --- FINAL UPDATE OF UNCERTAINTIES OF MIXING RATIOS WHEN APPROPRIATE
      INDXX = ISMIX
      NPGAS = 0
      DO KK = 1, NRET
         IF (IRTYPE(KK) /= 1) THEN
            N = IRTYPE(KK)
            NPGAS = NPGAS + 1
            DO K = 1, N
               INDXX = INDXX + 1
               X(KK,K) = XHAT(INDXX)*XORG(KK,K)
              !print *, 'vmr',indxx,shat(indxx,indxx)
               !SIG(K,NPGAS) = SQRT(ABS(SHAT(indxx,indxx)))*XORG(KK,K)
               SIG(K,NPGAS) = SQRT(ABS(SHAT(indxx,indxx)))*X(KK,K)
            END DO
         ELSE
            INDXX = INDXX + 1
            X(KK,:KMAX) = XHAT(INDXX)*XORG(KK,:KMAX)
              !print *, 'vmr',indxx,shat(indxx,indxx)
            SERR = SQRT(ABS(SHAT(indxx,indxx)))
            WRITE (16, 350) NAME(IGAS(KK)), XHAT(INDXX), SERR
         ENDIF
      END DO

! --- PRINT OUT FINAL BACKGROUND PARAMETERS
      IF (NBACK > 1) THEN
         WRITE (16, 3006)
         DO I = 1, NFITS
            SELECT CASE (NBACK)
            CASE (2)
               J = I*(NBACK - 1)
              !print *, 'back',j,shat(j,j)
               SIGB = SQRT(ABS(SHAT(J,J)))
               WRITE (16, 3007) I, XHAT(J), SIGB
            CASE (3)
               J = I*(NBACK - 2)
              !print *, 'back',j,shat(j,j)
               SIGB = SQRT(ABS(SHAT(J,J)))
               SIGC = SQRT(ABS(SHAT(J+1,J+1)))
               WRITE (16, 3007) I, XHAT(J), SIGB, XHAT(J+1), SIGC
            END SELECT
         END DO
      ENDIF

!  --- PRINT OUT FINAL WAVENUMBER SHIFTS
!  --- CONVERT PARAMETER TO WAVENUMBERS
      IF( ISPARM > 0 ) THEN
         WRITE( 16, 3008)
         SELECT CASE (ISPARM)
         CASE (1)
            WRITE( 16, 3011)
            J = NBKFIT+1
            WSHFT = 0.5D0*(WAVE3(1)+WAVE4(1))*((WAVFAC + XHAT(J)) - 1.D0)
            SWSHFT = SQRT(ABS(SHAT(J,J)))
            SWSHFT = 0.5D0*(WAVE3(1)+WAVE4(1))*((WAVFAC + SWSHFT) - 1.D0)
            WRITE (16, 3009) WSHFT, SWSHFT
         CASE (2)
            WRITE( 16, 3012)
            DO I=1, NBAND
               J = NBKFIT+I
               WSHFT = 0.5D0*(WAVE3(I)+WAVE4(I))*((WAVFAC + XHAT(J)) - 1.D0)
               SWSHFT = SQRT(ABS(SHAT(J,J)))
               SWSHFT = 0.5D0*(WAVE3(1)+WAVE4(1))*((WAVFAC + SWSHFT) - 1.D0)
               WRITE (16, 3014) I, WSHFT, SWSHFT
            ENDDO
         CASE (3)
            WRITE( 16, 3013)
            DO IBAND=1, NBAND
               N = NSCAN(IBAND)
               DO I=1, N
                  J = NBKFIT + IBAND + I - 1
                  WSHFT = 0.5D0*(WAVE3(I)+WAVE4(I))*((WAVFAC + XHAT(J)) - 1.D0)
                  SWSHFT = SQRT(ABS(SHAT(J,J)))
                  SWSHFT = 0.5D0*(WAVE3(1)+WAVE4(1))*((WAVFAC + SWSHFT) - 1.D0)
                  WRITE (16, 3015) IBAND, I, WSHFT, SWSHFT
               ENDDO
            ENDDO
         END SELECT
      ENDIF

!  --- PRINT OUT ZERO LEVEL OFFSETS - RETRIEVED OR NOT
      IF (NZERO /= 0) THEN
         K = NBKFIT + NSHIFT
         WRITE (16, 3001)
         DO I = 1, NBAND
            !IF (IZERO(I) == 0) CYCLE
            N = NSCAN(I)
            DO J = 1, N
               K = K + 1
               IF( IZERO(I) == 1 ) THEN
              !print *, 'zero',j,shat(j,j)
                  SIGZ = SQRT(ABS(SHAT(K,K)))
                  WRITE (16, 3002) I, J, XHAT(K), SIGZ
               ELSE
                  WRITE (16, 3010) I, J, ZSHIFT(I,J), "      NOT FIT"
               ENDIF
            END DO
         END DO
      ENDIF

!  --- PRINT OUT SOLAR CO PARAMETERS
!  --- PRINTS IF THEY ARE USED REGARDLESS OF WHETHER THEY ARE FIT
      IF (IFCO == 1) THEN
         CPARM(4) = CPARM(4) - 1.D0
         !CPARM(5) = CPARM(5) - 1.D0
         WRITE (16, 3003)
         WRITE (16, 3004) (CPNAM(I),CPARM(I),I=1,5)
      ENDIF

!  --- PRINT OUT FINAL CHANNEL PARMS ---------------!PWJ
      CALL PRINT_CHANNEL_PARMS (16)              !PWJ

!  --- SUM UP COLUMNS
      DO KVERT = 1, NMASS
         IF (KODE(KVERT) == 999) GO TO 401
      END DO
      GO TO 700
  401 CONTINUE


!  --- SUM UP COLUMNS
      DO I = 1, NRET
         VERSUM(I,1) = X(I,1)*CCC(KVERT,1)
         VOSUM(I,1)  = XORG(I,1)*CCC(KVERT,1)
         IF (IRTYPE(I) .NE. 1) FX(I) = (SIG(1,I)*CCC(KVERT,1))**2
         DO K = 1, KMAX
            VERSUM(I,K) = VERSUM(I,K-1) + X(I,K)*CCC(KVERT,K)
            VOSUM(I,K)  = VOSUM(I,K-1)  + XORG(I,K)*CCC(KVERT,K)
            IF (IRTYPE(I) .NE. 1) FX(I) = FX(I) + (SIG(K,I)*CCC(KVERT,K))**2
         END DO
         IF (IRTYPE(I) .NE. 1) FX(I) = SQRT(ABS(FX(I)))
         IF( I == 1 ) SERR = 100.0D0*FX(I)/VERSUM(I,KMAX)
      END DO
      AIRCOL = 0.0D0
      DO K = 1, KMAX
         AIRCOL = AIRCOL + CCC(KVERT,K)
      ENDDO

!  --- PRINT OUT RETRIEVED  PROFILES
      PRINT *,''
      NPGAS = 0
      DO K = NRET, 1, -1
!        print *, irtype(k)
         IF (IRTYPE(K) == 1) CYCLE
         NPGAS = NPGAS + 1
         N = IRTYPE(K)
         PRINT 408, NAME(IGAS(K)), VERSUM(K,N), FX(K), 100.0D0*FX(K)/VERSUM(K,N)
         WRITE(16,408) NAME(IGAS(K)), VERSUM(K,N), FX(K), 100.0D0*FX(K)/VERSUM(K,N)
         WRITE (16, 406) !NAME(IGAS(K))
         DO KK = 1, N
            WRITE (16, 407) Z(KK), ZBAR(KK), XORG(K,KK), X(K,KK), SIG(KK,NPGAS)&
               , VOSUM(K,KK), VERSUM(K,KK)
!           WRITE(16,407) KK,ZBAR(KK),XORG(K,KK),X(K,KK),SIG(KK,NPGAS),
         END DO
      END DO

      IF (IRTYPE(1) /= 1) THEN
         NPGAS = 1
         OPEN( 81, FILE='PRFS.out' )
         WRITE (81, 409)
         DO KK = 1, N
           WRITE (81, 407) Z(KK), ZBAR(KK), XORG(NPGAS,KK), X(NPGAS,KK), SIG(KK,NPGAS), &
                           XORG(NPGAS,KK)*CCC(KVERT,KK), X(NPGAS,KK)*CCC(KVERT,KK), &
                           SQRT( SA(ISMIX+KK,ISMIX+KK) )
         END DO
      ENDIF


! --- WRITING OUT OBSERVED, CALCULATED, AND DIFFERENCES - pbpfile
! --- AT EACH POINT TO TAPE8
      INDXX = 0
      WRITE (8, *) NFITS
      DO IBAND = 1, NBAND
         N = NSCAN(IBAND)
         IF (N == 0) CYCLE
         DO J = 1, N
            JSCAN = ISCAN(IBAND,J)
!           WRITE (8, 37905) ISPEC(JSCAN), SPAC, NPRIM(IBAND), WAVE3(IBAND), &
!               WAVE4(IBAND), Z(KZTAN(JSCAN))
            WRITE (8, 37905) ISPEC(JSCAN), SPAC, NPRIM(IBAND), WSTART(IBAND), &
               WSTOP(IBAND), Z(KZTAN(JSCAN))
            IB = 0
 3790       CONTINUE
            IA = IB + 1
            IB = IA + 11
            IB = MIN0(NPRIM(IBAND),IB)
            FX(:IB-IA+1) = TOBS(IA+INDXX:IB+INDXX) - YHAT(IA+INDXX:IB+INDXX)
            WAVE = WSTART(IBAND) + (IA - 1)*SPAC
            WRITE (8, 3794) WAVE, (TOBS(IOUT+INDXX),IOUT=IA,IB)
            WRITE (8, 3795) (YHAT(IOUT+INDXX),IOUT=IA,IB)
            WRITE (8, 3795) (FX(IOUT-IA+1),IOUT=IA,IB)
            IF (IB < NPRIM(IBAND)) GO TO 3790
            INDXX = INDXX + NPRIM(IBAND)
         END DO
      END DO

!  --- OUTPUT FILE OF FINAL MIXING RATIOS AND COLUMNS TO TAPE18 - statevec
      OPEN(UNIT=18, FILE=TFIL18, STATUS='unknown', ERR=5553, POSITION='asis')
      WRITE (18, *) NLEV
      WRITE (18, *) 'z (Mid-points, Layer Boundaries are in PT File)'
!      WRITE(18,*)'z'
      WRITE (18, 505) (ZM(I),I=1,NLEV)
      WRITE (18, *) 'p'
      WRITE (18, 506) (PMB(I),I=1,NLEV)
      WRITE (18, *) 't'
      WRITE (18, 505) (T(I),I=1,NLEV)
      WRITE (18, *)
      WRITE (18, *) NRET
      DO I = 1, NRET
         WRITE (18, 507) 'A Priori', NAME(IGAS(I))
         WRITE (18, 506) VOSUM(I,NLEV)
         WRITE (18, 506) (XORG(I,J),J=1,NLEV)
         WRITE (18, 507) 'Retrieved', NAME(IGAS(I))
         WRITE (18, 506) VERSUM(I,NLEV)
         WRITE (18, 506) (X(I,J),J=1,NLEV)
      END DO
      WRITE (18, *)
      WRITE (18, *) ISMIX
      WRITE (18, 502) (PNAME(I),I=1,ISMIX)
      WRITE (18, 506) (XAPR(I),I=1,ISMIX)
      WRITE (18, 506) (XHAT(I),I=1,ISMIX)
      CLOSE(18)

!  --- CALCULATE DEGREES OF FREEDOM FOR SIGNAL USING APOSTERIORI SOLUTION
      !print *, NVAR, 'NVAR'
      IF( IRTYPE(1) .NE. 1 ) CALL DOFS(NFIT,NVAR,ISMIX,NLEV)

!  --- SUMMARY FILE
      OPEN(UNIT=20, FILE=TFIL20, STATUS='UNKNOWN', ERR=5554, POSITION='ASIS')
      WRITE (20, *) NRET
      WRITE (20, 502) (NAME(IGAS(I)),I=1,NRET)
      WRITE (20, *) (IRTYPE(I),I=1,NRET)
      WRITE (20, 506) (VOSUM(I,NLEV),I=1,NRET)
      WRITE (20, *) NBAND
      WRITE (20, 505) (WAVE3(I),WAVE4(I),I=1,NBAND)
      WRITE (20, *)
      WRITE (20, 505) PMAX, FOVDIA, RMS, DOF
      WRITE (20, 506) (VERSUM(I,NLEV),I=1,NRET)
      WRITE (20, *) ITER, MAXIT1, CNVERG, DIVWARN
      WRITE (20, 3886) TFIL18
      WRITE (20, 3886) TFIL08
      WRITE (20, 3886) TFIL16
      CLOSE(20)


!  --- SHORT FILE
      WRITE (31, 460) (NAME(IGAS(I)),IRTYPE(I),I=1,NRET)
!      WRITE(31,461) ( VOSUM(I,NLEV), I=1, NRET )
      WRITE (31, 461) (VERSUM(I,NLEV),I=1,NRET)
      WRITE (31, 462) ITER, MAXIT1, RMS, NVAR, CNVERG, DIVWARN, DOF, SERR, SNR, AIRCOL
      DO K = NRET, 1, -1
        IAT = 0
        IBT = 0
        ICT = 0
        IF (IRTYPE (K) .GT. 1) THEN
           DO KK = 1, NLEV
!  --- SET THE FOLLOWING VALUES IN THE IF STMNTS TO GET 3 PARTIAL COLUMNS OF YOUR CHOICE
           IF (ZBAR(KK) .GE. 0.0) IAB = KK
           IF (ZBAR(KK) .LT. 9.0 .AND. IAT .EQ. 0) IAT = KK  ! 0km - 9km
           IF (ZBAR(KK) .GE. 9.0) IBB = KK
           IF (ZBAR(KK) .LT. 22.0 .AND. IBT .EQ. 0) IBT = KK  ! 9km - 22km
           IF (ZBAR(KK) .GE. 22.0) ICB = KK
           IF (ZBAR(KK) .LT. 81.0 .AND. ICT .EQ. 0) ICT = KK  ! 22km - top
           END DO
              WRITE (31, 464) NAME (IGAS (K) ) , RMS, DOF, SERR, SNR,   &
               VERSUM (K, IAB) - VERSUM (K, IAT),     &
               VERSUM (K, IBB) - VERSUM (K, IBT),     &
               VERSUM (K, ICB) - VERSUM (K, ICT), VERSUM(K,NLEV), AIRCOL
        ENDIF
      END DO

      CLOSE(31)

!  --- PRINT A SHORT SUMMARY TO THE CONSOLE

      PRINT *,''
      PRINT 460, ( NAME(IGAS(I)), IRTYPE(I), I=1, NRET )
      PRINT 461, ( VERSUM(I,NLEV), I=1, NRET )
      PRINT 462, ITER, MAXIT1, RMS, NVAR, CNVERG, DIVWARN, DOF, SERR, SNR, AIRCOL
      PRINT *,''


!  --- MEAN ALTITUDE, VMRS, AND RETRIEVED COLUMNS TO TAPE18
!      WRITE(18,570) ZBAR(1),(X(I,1),VERSUM(I,1),I=1,NRET)
!      DO 471 K=2,MAXRET
!      WRITE(18,570) ZBAR(K),(X(I,K),VERSUM(I,K),I=1,NRET)
!  471 CONTINUE

! --- UNCOMMENT NEXT LINE TO ACTIVATE OUTPUT OF RETRIEVED MIX FILE
      CALL MIXOUT (MAXRET, KVERT)

  700 CONTINUE

      CALL CPU_TIME (END_TIME)
      !WRITE (16, *) 'CPU OR ELAPSED TIME = ', END_TIME - START_TIME
      PRINT *, 'CPU or Elapsed Time = ', END_TIME - START_TIME

      CLOSE(16)
      CLOSE(8)
      CLOSE(13)
      CLOSE(14)
      CALL RELEASE_MEM
      IF(IFCO /=0 ) CALL SOLARFH ( 2 )
      RETURN
 5551 CONTINUE
      WRITE (16, 2221) TFIL08
      CLOSE(16)
      RETURN
 5552 CONTINUE
      WRITE (16, 2222) TFIL16
      CLOSE(16)
      RETURN
 5553 CONTINUE
      WRITE (16, 2223) TFIL18
      CLOSE(16)
      RETURN
 5554 CONTINUE
      WRITE (16, 2224) TFIL20
      CLOSE(16)
      RETURN
  556 CONTINUE
      WRITE (16, 223)
      WRITE (6, *) 'NVAR =', NVAR, ' TO BIG, NMAX = ', NMAX
      CLOSE(16)
      RETURN
  557 CONTINUE
      WRITE (16, 224)
      WRITE (6, *) 'NFIT=', NFIT, 'TO BIG, NFITMX =', NFITMX
      CLOSE(16)
      RETURN
  664 CONTINUE
      WRITE (16, 591)
      CLOSE(16)
      RETURN
  665 CONTINUE
      WRITE (16, 592)
      CLOSE(16)
      RETURN
  666 CONTINUE
      WRITE (16, 333) TFIL13
      CLOSE(16)
      RETURN
 6661 CONTINUE
      WRITE (16, 3331) TFIL07
      CLOSE(16)
      RETURN
 6662 CONTINUE
      WRITE (16, 3332) TFIL09
      CLOSE(16)
      RETURN
  667 CONTINUE
      WRITE (16, 250)
      CLOSE(16)
      RETURN
  668 CONTINUE
      WRITE (16, 251)
      CLOSE(16)
      RETURN
  669 CONTINUE
      WRITE (16, 2225) TFIL31
      CLOSE(16)
      RETURN
 4441 CONTINUE
      WRITE (16, *) 'ERROR OPENING ', TFIL61
      CLOSE(16)
      RETURN
 4442 CONTINUE
      WRITE (16, *) 'ERROR OPENING OUTPUT SPECTRA'
      WRITE (16, *) 'FILENAME: "', OUT_SPC, '"'
      CLOSE(16)
      RETURN
 4443 CONTINUE
      WRITE (16, *) 'ERROR OPENING SA INPUT MATRIX'
      WRITE (16, *) 'FILENAME: "', TFIL62, '"'
      CLOSE(16)
      RETURN
  100 FORMAT(/,' PRESSURE-TEMPERATURE PROFILE FROM TAPE9')
  101 FORMAT(/,' MASS PATH DATA FROM TAPE7 IN CM*ATM'/)
  102 FORMAT(8I5)
  103 FORMAT(8E10.4)
  106 FORMAT(6(1P,E12.4))
  104 FORMAT(I5,F10.1,F9.4,I5)
  105 FORMAT(5F10.3)
  201 FORMAT(/,' ENTER STARTING, ENDING WAVENUMBERS FOR BANDPASS',I3,/,&
         ' NUMBER OF RETRIEVAL GASES (1-4)'/,&
         ' FIT ZERO TRANSMISSION LEVEL (0=NO, 1=YES)'/,' NUMBER OF BEAMS'/,&
         ' CHANNEL MODEL ')                      !pwj

 2221 FORMAT(/,' OUTPUT FILE OPEN ERROR-UNIT 8'/,' Filename: "',A,'"')
 2222 FORMAT(/,' OUTPUT FILE OPEN ERROR-UNIT 16'/,' Filename: "',A,'"')
 2223 FORMAT(/,' OUTPUT FILE OPEN ERROR-UNIT 18'/,' Filename: "',A,'"')
 2224 FORMAT(/,' OUTPUT FILE OPEN ERROR-UNIT 20'/,' Filename: "',A,'"')
 2225 FORMAT(/,' OUTPUT FILE OPEN ERROR-UNIT 31'/,' Filename: "',A,'"')
  223 FORMAT(/,' ABORT--TOO MANY VARIABLES')
  224 FORMAT(/,' ABORT--TOO MANY SPECTRAL DATA POINTS')
  250 FORMAT(/,' Can only retrieve apodization parameters for polynomial'/,&
         ' (irteap must be 0 unless ieap=2)')
  251 FORMAT(/,' Can only retrieve phase parameters for polynomial'/,&
         ' (irtephs must be 0 unless iephs=2)')
  333 FORMAT(/,' INPUT FILE OPEN ERROR-UNIT 13'/,' Filename: "',A,'"')
 3331 FORMAT(/,' INPUT FILE OPEN ERROR-UNIT 7'/,' Filename: "',A,'"')
 3332 FORMAT(/,' INPUT FILE OPEN ERROR-UNIT 9'/,' Filename: "',A,'"')
  350 FORMAT(/,' MOLECULE = ',A7,' PROFILE SCALE FACTOR =',F7.4,' +/-',F7.4)
!  376 FORMAT(/,' THERE ARE ',I5,' DATA POINTS')
!  381 FORMAT(/,' FINAL RESULTS FOR MIXING RATIO RETRIEVAL'/,&
!         ' RETRIEVAL GASES =',10(A7,2X),/,5X,' HEIGHT',6X,'P(MB)  VMR')
!  404 FORMAT(/,' VERTICAL COLUMN AMOUNTS (MOLECULES CM-2)'/,&
!         ' RETRIEVAL GASES = ',4(A7,10X))
!  405 FORMAT(19X,4(4X,D12.4))
  406 FORMAT('  RETRIEVED VERTICAL PROFILE:',/,&
      '  Z[km] ZBAR[km] APRIORI_VMR RETRIEVED_VMR  SIGMA_VMR  APRIORI_COL  RETR&
      &IEVE_COL')
  407 FORMAT(2(F7.2),6(ES13.4))
 408  FORMAT(/' GAS: ', A7, ' COLUMN: ', ES12.4, ' +/- ',ES12.4,1X,F6.3,'%')
  409 FORMAT('  Z[km] ZBAR[km] APRIORI_VMR RETRIEVED_VMR  SIGMA_VMR  APRIORI_COL  RETR&
      &IEVE_COL  VARIANCE')


  460 FORMAT(7(2X,A7,':',I2))
  461 FORMAT(7(1P,E12.4))
  462 FORMAT("Itr/Mx:",I2.2,"/",I2.2," %RMS=",F5.3," FitPrm=",I3,' Cvrg:',L1, &
         ' Dvrg:',L1," DOFS=",F5.3, " %CERR=",F4.1, " SNR=",F5.0, " AIRCOL=",ES12.4)
!  463 FORMAT(' FIT   SLOPE       SIGMA     CURVATURE     SIGMA')
 464  FORMAT('pcol ', A7, 2(F6.3,1X), 2(F6.1,1X), 7ES12.4)

!  500 FORMAT(A1)
!  501 FORMAT(A7)
  502 FORMAT(5(1X,A14))
!  503 FORMAT(1X,A1)
  504 FORMAT(2I5,F10.3)
  505 FORMAT(5(1X,F9.3))
  506 FORMAT(5(1X,1P,E14.4))
  507 FORMAT(A20)
!  504 FORMAT(2I5,2F10.3)
  520 FORMAT(/,' INPUT FOUR PARAMETERS -',/,' NUMBER OF SPECTRA',/,&
         ' DEFAULT SIGNAL-TO-NOISE'/,' CONVERGENCE TOLERENCE CRITERION',/,&
         ' NUMBER OF NOT FIT GASES')

  521 FORMAT(/,"NOT FITTED GASES INCLUDED IN CALCULATION",/," GAS     SCALE")
  522 FORMAT(A7,F7.4)

  530 FORMAT(/,' INPUT TWO PARAMETERS -',/,' SPECTRUM CODE',/,&
         ' NUMBER OF BINARY FILES (MAX=3)')
  532 FORMAT(/,' INPUT IFIX FOR EACH PARAMETER (0=NO,1=YES)')
  540 FORMAT(/,' ABORT ** SPECTRUM NOT IN MASS PATH DATA')
  550 FORMAT(A,F6.2,A)
!  570 FORMAT(F6.2,4(1P,E16.8))
!  571 FORMAT(F8.2,4(1P,E10.3))
  588 FORMAT(4F10.0)
!  589 FORMAT(F10.2,20X,1P,E10.3,0P,F10.3,F10.4)
  590 FORMAT(F10.2,2(1P,E10.3,0P,F10.3))
  591 FORMAT(/,' ABORT NBACK OUT OF RANGE (1-3 VALID)')
  592 FORMAT('/ ABORT ISPARM OUT OF RANGE (0-3 VALID)')
!  602 FORMAT(/,' INPUT REFERENCE TEMPERATURE OF SOLAR LINE DATA',/,&
!         ' SOLAR LAYER TEMPERATURE (K)')
!  603 FORMAT(/,' INPUT SOLAR LINE SIMULATION PARAMETERS',/,&
!         ' MINNAERT LIMITING RESIDUAL INTENSITY',/,&
!         ' SOLAR GAS COLUMN DENSITY (CM*ATM)',/,&
!         ' MICROTURBULENCE PARAMETER (DOPPLER HALF WIDTH MULTIPLIER)',/,&
!         ' DIFFERENTIAL SOLAR LINE WAVENUMBER SHIFT'/,&
!         ' LORENTZ WIDTH FOR ALL LINES (CM-1)')
  603 FORMAT(/,' INPUT SOLAR LINE SIMULATION PARAMETERS',/,&
         ' DIFFERENTIAL SOLAR LINE WAVENUMBER SHIFT')
  610 FORMAT(/,' ABORT** GAS IS NOT IN LIST OF RETRIEVAL GASES',/,' GAS =',A7,&
         ' BANDPASS RANGE =',F10.4,' TO',F10.4,' CM-1')
!  888 FORMAT(5(1P,E14.7,1X))
! 1000 FORMAT(F9.4,E9.3,F5.3,F10.4,I3,6A7)
!1001 FORMAT(' SFIT2 VERSION 3.7 - 7 JAN 2000')
! 1001 FORMAT(' SFIT2 VERSION 3.7-A  -21 MAR 2000')
! 1001 FORMAT(' SFIT2 VERSION 3.7-B  -06 APR 2000')
! 1001 FORMAT(' SFIT2 VERSION 3.7-C  -06 APR 2000')
!1001 FORMAT(' SFIT2 VERSION 3.8  -11 JUN 2001')
!1001 FORMAT(' SFIT2 VERSION 3.8  -19 JUN 2001')
 1002 FORMAT(2F10.4,I5,F10.4,I5,I5,A6)           !pwj
 1003 FORMAT(/,' ENTER NAME OF RETRIEVAL GAS FOR BANDPASS #',I3,/,&
         ' MINIMUM SOLAR ZENITH ANGLE FOR RETRIEVAL',/,&
         ' MAXIMUM SOLAR ZENITH ANGLE FOR RETRIEVAL')
 1004 FORMAT(A7,2I5)
 1005 FORMAT(1X,A7,2I5)
 1008 FORMAT(/,/,'FM Parameters:',/,'wavfac,   pmax,   omega,     iap, ',&
         'nband,  ifpsr,  ieap,  neap,  iephs,  nephs')
 1018 FORMAT(F10.7,F10.2,F10.5,7(I7))
 1009 FORMAT(/,'Retr. Switches:',/,'isparm, nback, ifco, ifdiff, ',&
         'iphase, irteap, irtephs')
 1019 FORMAT(10(I7))
!                                                !pwj
 1010 FORMAT(/,'A Priori and Uncertainty:',/,&
         'wshft,    swshft,   bcksl,    sbcksl,  bckcrv,  sbckcrv,',/,&
         'copar,    scopar,   phs,      sphs,    szero,   eappar,',/,&
         'seappar,  ephspar,  sephspar ,chan_scale,  schan_scale')

10101 FORMAT(6(F10.7))
! 2001 FORMAT(/,' Parameter list:',/,'FM parameters:',/,&
!         'Wavfac - APPROXIMATE WAVENUMBER SCALE MULTIPLIER,',/,&
!         'PMAX - MAXIMUM PATH DIFFERENCE CM',/,&
!         'OMEGA - DIAMETER OF FIELD OF VIEW IN MRAD',/,&
!         'iap - imposed apodization code (i.e. deliberate apodization',/,&
!         '    of interferogram) - routine apdz',/,&
!         ' NBAND - NUMBER OF BANDPASSES (1-125)',/,&
!         ' IFPS - INCLUDE PRESSURE-INDUCED LINE SHIFTS?',/,&
!         '     IFPS=0 YES (READ FROM LINELIST)',/,&
!         '     IFPS=1 NO (ZERO SHIFT ASSUMED)',/,&
!         ' ieap - empirical apodization code (i.e. due to instrument)',/,&
!         '     ieap=0 no empirical apodization',/,&
!         '     ieap=1 a tabular function is read in',/,&
!         '     ieap=2 a polynomial of order neap',/,&
!         '     ieap=3 a Fourier series of order neap',/,&
!         '     ieap=4 a tabular instrument function is read in.',/,&
!         '             This is output from F. Hase, T. Blumenstock',/,&
!         '             "linefit" prog ',/,' neap - see ieap')
! 2002 FORMAT(/,' iephs - empirical phase error code',/,&
!         '     iephs=0 no empirical phase function ',/,&
!         '     iephs=1 a tabular function is read in',/,&
!         '     iephs=4 a tabular instrument function is read in.',/,&
!         '             This is output from F. Hase, T. Blumenstock',/,&
!         '             "linefit" prog ',/,&
!         '     iephs=2 a polynomial of order nephs',/,' nephs - see iephs',/,&
!         ' Retrieval switches:',/,&
!         ' ISPARM - WAVELENGTH SHIFT PARAMETER (1, 2, OR 3)',/,&
!         '     ISPARM=1 SINGLE SHIFT FOR ALL BANDPASSES',/,&
!         '     ISPARM=2 INDEPENDENT SHIFT FOR EACH BANDPASS',/,&
!         '     ISPARM=3 INDEPENDENT SHIFT FOR EACH FITTING',/,&
!         '     NBACK - NUMBER OF BACKGROUND PARAMETERS (1-3)',/,&
!         ' IFCO - SOLAR CO PARAMETER (0 OR 1)',/,'     IFCO=0 NO SOLAR CO',/,&
!         '     IFCO=1 INCLUDE SOLAR CO',/,&
!         ' IFDIFF - DIFFERENTIAL WAVENUMBER SHIFT FOR RETRIEVAL GASES?',/,&
!         '     IFDIFF=0 ONE SHIFT FOR ALL RETRIEVED MOLECULES',/,&
!         '     IFDIFF=1 INDEPENDENT SHIFTS FOR ALL RETRIEVED MOLECULES')
!!                                                !pwj
! 2003 FORMAT(/,' IPHASE - SIMPLE PHASE ERROR PARAMETER (0-1) ',/,&
!         '     IPHASE=0  NO PHASE ERROR ASSUMED ',/,&
!         '     IPHASE=1  VALUE RETRIEVED FOR EACH SPECTRUM AND BANDPASS',/,&
!         ' irteap - 0=use empirical apod. in FM, do not retr. params.',/,&
!         '          1=retrieve empirical apodization parameters',/,&
!         '            (only available if ieap=2)',/,&
!         ' irtephs - 0=use empirical phase in FM, do not retr. params.',/,&
!         '           1=retrieve empirical phase parameters',/,&
!         '            (only available if iephs=2)',/,&
!         'A Priori and uncertainty:',/,' wshft,swshft - wavelength shift',/,&
!         ' bcksl,sbcksl - background slope',/,&
!         ' bckcrv,sbckcrv - background curvature',/,&
!         ' copar,scopar - solar CO Minnaert parameters',/,&
!         ' phs,sphs - phase error',/,' szero - uncertainty in zero level',/,&
!         ' eappar,seappar - scale factor for empirical apodization',/,&
!         ' parameters',/,&
!         ' chan_scale,schan_scale - scale factor for channel parms')

 3001 FORMAT(/,' RETRIEVED ZERO LEVEL OFFSETS',/,&
               'BAND    ISCAN     ZERO     SIGMA')
 3002 FORMAT(I3,I9,2ES13.5)
 3003 FORMAT(/,' RETRIEVED SOLAR SIMULATION PARAMETERS:')
 3004 FORMAT(2(1X,A14,'=',1P,E13.4,1X))
! 3005 FORMAT(/,' RETRIEVED WAVENUMBER SCALE FACTOR =',F12.9)
 3006 FORMAT(/' RETRIEVED BACKGROUND PARAMETERS:'/,&
         ' BAND   SLOPE       SIGMA     CURVATURE     SIGMA')
 3007 FORMAT(I3,4(1P,E12.4))
 3008 FORMAT(/,' RETRIEVED WAVENUMBER SHIFTS:')
 3009 FORMAT(2ES13.5)
 3010 FORMAT(I3,I9,ES13.5,A)
 3011 FORMAT('  SHIFT          SIGMA')
 3012 FORMAT(' BAND     SHIFT          SIGMA')
 3013 FORMAT(' BAND   SCAN      SHIFT          SIGMA')
 3014 FORMAT(I3, 3X, 2ES13.5)
 3015 FORMAT(I5, I5, 3X, 2ES13.5)

 3695 FORMAT(/,' NFIT =',I5,' NVAR =',I3)
 3696 FORMAT(/,' PRINT OUT OF PARAMETERS FOR EACH ITERATION:',/)
37905 FORMAT(I12,1P,E25.15,I12,0P,F25.15,/,2F25.15)
 3885 FORMAT(/,' BINARY INPUT SPECTRUM FILE NAME:')
 3886 FORMAT(A)
 3887 FORMAT(1X,A)
 3794 FORMAT(F10.4,12ES15.5)
 3795 FORMAT(10X,12ES15.5)
      RETURN
      END SUBROUTINE SFIT2
